/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitRelBreitWigner.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2009 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a RelBreitWigner distribution.

#include "AFit/AFitRelBreitWigner.hh"
#include "AFit/AFitRelBreitWignerPdf.hh"
#ifdef __BABARROOFIT__
#else
#endif

#include "TIterator.h"

ClassImp(AFitRelBreitWigner)
  ;

AFitRelBreitWigner::AFitRelBreitWigner(RooAbsReal& x, TString name)
  : mean(name+"mean", "Mean of resonance", 0.77, 0.0, 1.0)
    , width(name+"width", "Width of resonance", 0.150, 0.0, 2.0)
    , spin(name+"spin", "spin of resonance", 1., 0.0, 2.0)
    , radius(name+"radius", "form factor radius", 3.0, 0.0, 10.0)
    , mass_a(name+"mass_a", "mass of daughter A", 0.135, 0.0, 10.0)
    , mass_b(name+"mass_b", "mass of daughter B", 0.135, 0.0, 10.0)
 {
  // Constructor
  _name     = name;

  _x = &x;
  varSet.addOwned(mean);
  varSet.addOwned(width);
  varSet.addOwned(spin);
  varSet.addOwned(radius);
  varSet.addOwned(mass_a);
  varSet.addOwned(mass_b);

  readDataCard();
}

void AFitRelBreitWigner::buildPdf() {
  _thePdf = new AFitRelBreitWignerPdf(_name, "RelBreitWigner PDF", *_x, mean, width, spin, radius, mass_a, mass_b);
}
