/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitStepFunction.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2008 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single Step Function distribution.

#include "AFit/AFitStepFunction.hh"
#include "AFit/AFitStepFunctionPdf.hh"
#ifdef __BABARROOFIT__
// RooFit includes
#else
// RooFit includes
#endif

#include "TIterator.h"

ClassImp(AFitStepFunction)
  ;

AFitStepFunction::AFitStepFunction(RooAbsReal& x, TString name)
  : limit(name+"limit", "Step Function Limit", 0.0, 0.0, 1.0)
  , veto(name+"veto", "veto region")
 {
  // Constructor
  cout << ClassName() << ": ctor" << endl;
  _name     = name;
   _x = &x;

  veto.defineType("false");
  veto.defineType("true");
  veto.setLabel("false");

  varSet.addOwned(limit);
  varSet.addOwned(veto);

  readDataCard();
}

void AFitStepFunction::buildPdf() {
  cout << ClassName() << ": buildPdf" << endl;
  limit.Print();
  veto.Print();
  _thePdf = new AFitStepFunctionPdf(_name, "Step Function PDF", *_x, limit, veto);
  cout << ClassName() << ": pdf has been built" << endl;
}

