/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitVoigtianShape.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2008 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single Voigtian distribution.

#include "AFit/AFitVoigtianShape.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooVoigtian.hh"
#else
#include "RooVoigtian.h"
#endif

ClassImp(AFitVoigtianShape)
  ;

AFitVoigtianShape::AFitVoigtianShape(RooAbsReal& x, TString name)
  : mean(name+"mean", "Mean of Voigtian", 0.0, -10.0, 10.0)
    , width(name+"width", "Width of Voigtian", 1.0, 0.0, 10.0)
    , sigma(name+"sigma", "sigma parameter of Voigtian", 1.0, 0.0, 10.0)
    , Algorithm(name + "Algorithm", "Use fast or slow algorithm") 
 {
  // Constructor
  _name     = name;

  _x = &x;
  const RooArgSet * argVarSet = _x->getVariables();
  if(argVarSet->getSize() == 1) {
    TIterator * iter = argVarSet->createIterator();
    RooRealVar * var = (RooRealVar*)iter->Next();
    if(var){
      mean.setRange(var->getMin(), var->getMax());
      width.setRange(0.0,  var->getMax()-var->getMin());
      sigma.setRange(0.0,  var->getMax()-var->getMin());
    }
  }

  varSet.add(mean);
  varSet.add(width);
  varSet.add(sigma);
  varSet.add(Algorithm);

  Algorithm.defineType("fast");
  Algorithm.defineType("slow");
  Algorithm.setLabel("slow");   // default for RooFitModels/RooVoigtian.

  readDataCard();
}

void AFitVoigtianShape::buildPdf() {
  // Build the Pdf
  TString alg = Algorithm.getLabel();
  alg.ToLower();
  Bool_t kALG = kFALSE;
  if(!alg.CompareTo("fast")) kALG = kTRUE;

  _thePdf = new RooVoigtian(_name, "Voigtian PDF", *_x, mean, width, sigma, kALG);
}

