void resolutionFunction() {
  /*
   * Fit the deltat resolution function with a PDF that is a 
   * function of the resolution and sigmaDeltaT.  This would be the same as doing
   * a physics fit with deltat and sigma delta t.
   */
  RooRealVar deltat("reso_dt", "dt", -10.0, 10.0);
  RooRealVar deltatErr("deltaterr", "sdt", 1.2, 0.0, 2.50);

  AFitResolution resoBld(&deltat, &deltatErr, "SigReso");
  resoBld.scaleCoreMean.setLabel("yes");
  resoBld.scaleTailMean.setLabel("yes");
  resoBld.scaleCoreWidth.setLabel("yes");
  resoBld.scaleTailWidth.setLabel("yes");
 
  resoBld.sigSig1.setRange(0.0, 2.0);
  resoBld.sigSig2.setRange(0.0, 5.0);
  resoBld.sigMean1.setRange(-2.0, 2.0);
  resoBld.sigMean2.setRange(-2.0, 2.0);
  resoBld.sigCoreFrac.setRange(0.0, 1.0);
  resoBld.sigTailFrac.setRange(0.0, 1.0);

  resoBld.sigSig1.setConstant(kFALSE);
  resoBld.sigSig2.setConstant(kFALSE);
  resoBld.sigMean1.setConstant(kFALSE);
  resoBld.sigMean2.setConstant(kFALSE);
  resoBld.sigCoreFrac.setConstant(kFALSE);
  resoBld.sigTailFrac.setConstant(kFALSE);

  RooAbsPdf * pdf = resoBld.getPdf();

  TFile f("examples/resolutionFunctionData.root");
  TTree * tree = (TTree*)f.Get("data");

  RooDataSet data("rds", "the data", tree , RooArgSet(deltat, deltatErr));
  data.Print("v");
  pdf->fitTo(data, "trh");

  RooDataSet * proto = data->reduce(RooArgSet(deltatErr));
  proto.Print("V");

  AFitProjectionPlot plotter;
  RooPlot * frame = plotter.makePlot(deltat, &data, pdf, proto);
  //RooPlot * frame = plotter.makePlot(deltat, &data, pdf);

  frame.Draw();
  //c1.SetLogy();
  //c1.Print("fig/testResolutionFunction_superb.png");
  //c1.Print("fig/testResolutionFunction_superb.eps");
  c1.Print("fig/testResolutionFunction_babar.png");
  c1.Print("fig/testResolutionFunction_babar.eps");
  c1.SetLogy();
  //c1.Print("fig/testResolutionFunction_superb_log.png");
  //c1.Print("fig/testResolutionFunction_superb_log.eps");
  c1.Print("fig/testResolutionFunction_babar_log.png");
  c1.Print("fig/testResolutionFunction_babar_log.eps");
}
