void simpdf2() {
  // get a fit model
  AFitMaster master("AFit/example/simpdf2.txt");
  RooAbsPdf * simpdf = master.getSimPdf();

  simpdf->Print();
  RooArgSet * compSet = simpdf->getComponents();
  RooArgSet * parSet = simpdf->getParameters(compSet);
  parSet->Print("V");

  RooArgSet argset;
  RooRealVar * bMes = (RooRealVar*)parSet->find("bMes");
  RooRealVar * bDeltaE = (RooRealVar*)parSet->find("bDeltaE");
  argset.add(*bMes);
  argset.add(*bDeltaE);

  // make prototype data set for the decay tag category
  RooCategory * decay = (RooCategory*)parSet->find("decay");
  RooArgSet aset;
  aset.add(*decay);
  RooDataSet proto("proto", "prototype of the decay category", aset);

  for(int i = 0; i < 800; i++) {
    decay->setLabel("JPsiK*0");
    proto.add(aset);
  }
  for(int i = 0; i < 1650; i++) {
    decay->setLabel("JpsiK0S");
    proto.add(aset);
  }
  for(int i = 0; i < 850; i++) {
    decay->setLabel("JpsiK0S_pi0pi0");
    proto.add(aset);
  }
  for(int i = 0; i < 400; i++) {
    decay->setLabel("Psi2SK0S");
    proto.add(aset);
  }

  // generate a toy sample using the category prototype
  AFitToy toy;
  RooDataSet * data = toy.generateToySample(simpdf, argset, 4300, &proto);
  data->Print("v");

  // fit the toy sample
  simpdf->fitTo(*data, "etrm");

  // make plots of the fitted result
  AFitProjectionPlot plotter;
  bMes->SetTitle("m_{ES} (GeV / c^{2})");
  bDeltaE->SetTitle("#Delta E (GeV)");
  RooPlot *bMes_jpsik0s        = plotter.makePlot("decay==0", *bMes, data, simpdf, 0);
  RooPlot *bMes_jpsik0s_pi0pi0 = plotter.makePlot("decay==1", *bMes, data, simpdf, 0);
  RooPlot *bMes_psi2sk0        = plotter.makePlot("decay==3", *bMes, data, simpdf, 0);
  RooPlot *bMes_jpsikst0       = plotter.makePlot("decay==2", *bMes, data, simpdf, 0);

  RooPlot *bDeltaE_jpsik0s        = plotter.makePlot("decay==0", *bDeltaE, data, simpdf, 0);
  RooPlot *bDeltaE_jpsik0s_pi0pi0 = plotter.makePlot("decay==1", *bDeltaE, data, simpdf, 0);
  RooPlot *bDeltaE_psi2sk0        = plotter.makePlot("decay==3", *bDeltaE, data, simpdf, 0);
  RooPlot *bDeltaE_jpsikst0       = plotter.makePlot("decay==2", *bDeltaE, data, simpdf, 0);

  TCanvas can("can", "");
  can.Divide(2,2);
  can.cd(1);
  bMes_jpsik0s->Draw();

  can.cd(2);
  bMes_jpsik0s_pi0pi0->Draw();

  can.cd(3);
  bMes_jpsikst0->Draw();

  can.cd(4);
  bMes_psi2sk0->Draw();

  can.Print("fig/simpdf_mes.eps");

  TCanvas can2("can2", "");
  can2.Divide(2,2);
  can2.cd(1);
  bDeltaE_jpsik0s->Draw();

  can2.cd(2);
  bDeltaE_jpsik0s_pi0pi0->Draw();

  can2.cd(3);
  bDeltaE_jpsikst0->Draw();

  can2.cd(4);
  bDeltaE_psi2sk0->Draw();

  can2.Print("fig/simpdf_de.eps");
}
